@@ -58,7 +58,6 @@ All other settings are optional:
   -io vddk-file=FILE           Override nbdkit-vddk-plugin file= parameter
   -io vddk-libdir=LIBDIR       VDDK library parent directory
   -io vddk-nfchostport=PORT    VDDK nfchostport
-  -io vddk-noextents=true      Avoid slow VDDK QueryAllocatedBlocks API
   -io vddk-port=PORT           VDDK port
   -io vddk-snapshot=SNAPSHOT-MOREF
                                VDDK snapshot moref
@@ -79,7 +78,6 @@ information on these settings.
         "file";
         "libdir";
         "nfchostport";
-        "noextents";
         "port";
         "snapshot";
         "thumbprint";
@@ -208,9 +206,6 @@ information on these settings.
       try Some (List.assoc "libdir" io_options) with Not_found -> None in
     let nfchostport =
       try Some (List.assoc "nfchostport" io_options) with Not_found -> None in
-    let noextents =
-      try bool_of_string (List.assoc "noextents" io_options)
-      with Not_found -> false in
     let port =
       try Some (List.assoc "port" io_options) with Not_found -> None in
     let snapshot =
@@ -318,35 +313,12 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
        *)
       Nbdkit.add_filter_if_available cmd "retry";
 
-      (* VDDK's QueryAllocatedBlocks API is infamously slow.  It appears
-       * to block all other requests while it is running.  This API is
-       * also only called during the copy phase, not during conversion
-       * (or if it is, extremely rarely).
-       *
-       * If fstrim was successful, then trimmed blocks are stored in
-       * the COW filter (see below), and so requests for extents stop
-       * at that layer.  However for areas of the disk that fstrim
-       * thinks contain data, we still have to go through to VDDK to
-       * fetch extents.
-       *
-       * We could therefore add nbdkit-noextents-filter here (below COW,
-       * above VDDK plugin) which stops extents requests from going
-       * to VDDK, which would stop QueryAllocatedBlocks ever being
-       * called.  In my testing this is a moderate performance win.
-       *
-       * However ... in the case where fstrim failed, or for filesystems
-       * or partitions on the disk that we don't understand, doing this
-       * would mean that those are copied completely, as there would be
-       * no extent data (nbdcopy will still sparsify them on the target,
-       * but we'd have to copy all the bits from VMware).  Because
-       * here we don't know if this is the case, be conservative and
-       * actually don't use this filter.
-       *
-       * If used, this filter should be close to the plugin and MUST
-       * be below the COW filter.
+      (* Add the count filter if available, to report bytes read.
+       * Since it writes a debug message, only do this if verbose.
+       * This should be close to the plugin so we're reporting what
+       * is read over the wire.
        *)
-      if noextents then
-        Nbdkit.add_filter_if_available cmd "noextents";
+      if verbose () then Nbdkit.add_filter_if_available cmd "count";
 
       (* Split very large requests to avoid out of memory errors on the
        * server.  Since we're using this filter, also add minblock=512
@@ -446,7 +418,7 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
         let wildcard =
           match files with
           | [] -> assert false (* can't happen, see assert above *)
-          | [f] -> f
+          | [f] -> fnmatch_escape f
           | files ->
              (* Calculate the longest common prefix across all the files,
               * then set the wildcard to this.
@@ -454,8 +426,7 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
               * XXX Is every file we want to read called *.vmdk?
               *)
              let prefix = String.longest_common_prefix files in
-             prefix ^ "*.vmdk" in
-        let wildcard = fnmatch_escape wildcard in
+             fnmatch_escape prefix ^ "*.vmdk" in
 
         let socket = sprintf "%s/in0" dir in
         On_exit.unlink socket;
